action

package
v0.0.0-...-6684bfc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 9, 2018 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CommitFile

func CommitFile(databaseName string, file string, comment string)

Commit a new file containing schema updates to a managed database.

func CopyDatabase

func CopyDatabase(source string, destination string, revision uint64)

Copy a full database to a destination at a particular revision.

func Diff

func Diff(databaseName string, revisionString string)

Copy a full database to a destination at a particular revision.

func InitialiseDatabase

func InitialiseDatabase(databaseName string)

Initialise a datbase to be managed.

func ListManagedDatabases

func ListManagedDatabases()

List all managed databases.

func ShowFullSql

func ShowFullSql(databaseName string, revision uint64)

Show a managed database's full SQL at a particular revision.

func ShowLog

func ShowLog(databaseName string)

Show the commit log for the passed database.

func ShowUpdateSql

func ShowUpdateSql(databaseName string, revision uint64)

Show a managed database's update SQL at a particular revision.

func UpdateSchemaToRevision

func UpdateSchemaToRevision(databaseName string, target uint64)

Show a managed database's full SQL at a particular revision.

Types

This section is empty.

Jump to